@@ -8,8 +8,10 @@ from rez.config import Config, get_module_root_config, _replace_config
 from rez.system import system
 from rez.utils.data_utils import RO_AttrDictWrapper
 from rez.packages import get_developer_package
+from rez.vendor.six import six
 import os
 import os.path
+import subprocess
 
 
 class TestConfig(TestBase):
@@ -237,8 +239,53 @@ class TestConfig(TestBase):
 
         self.assertEqual(c.packages_path, packages_path)
 
+    def test_8(self):
+        """Test CLI dict/list value JSON round trip."""
+        import json
+        import rez.cli._main
 
-if __name__ == '__main__':
+        cli_file = rez.cli._main.__file__
+
+        # python /path/to/rez/cli/_main.py config ...
+        config_args = [os.sys.executable, cli_file, "config"]
+
+        c = Config([self.root_config_file], locked=True)
+        env = {
+            key: value
+            for key, value in os.environ.items()
+            if not key.startswith("REZ_")
+        }
+
+        test_configs = {
+            "packages_path": ["/foo bar/baz", "/foo bar/baz hey", "/home/foo bar/baz"],
+            "platform_map": {"foo": {"bar": "baz"}},
+        }
+        for config_key, test_value in test_configs.items():
+            try:
+                # Test fetching default value
+                stdout = subprocess.check_output(
+                    config_args + ["--json", config_key],
+                    env=env,
+                )
+                self.assertEqual(
+                    six.ensure_str(stdout).strip(),
+                    six.ensure_str(json.dumps(getattr(c, config_key))),
+                )
+
+                # Test setting via env var and fetching custom value
+                test_json_value = six.ensure_str(json.dumps(test_value))
+                env["REZ_%s_JSON" % config_key.upper()] = test_json_value
+                stdout = subprocess.check_output(
+                    config_args + ["--json", config_key],
+                    env=env,
+                )
+                self.assertEqual(stdout.decode().strip(), test_json_value)
+            except subprocess.CalledProcessError as error:
+                print(error.stdout)
+                raise
+
+
+if __name__ == "__main__":
     unittest.main()
 
 
